CREATE SEQUENCE SEQ_ID_CTE_INFCTE
  INCREMENT 1
  MINVALUE 1
  MAXVALUE 9223372036854775807
  START 1
  CACHE 1;

ALTER TABLE SEQ_ID_CTE_INFCTE
  OWNER TO postgres;

CREATE TABLE OOBJ_CTE_INFCTE (
    id_infcte BIGINT NOT NULL DEFAULT nextval('SEQ_ID_CTE_INFCTE'::regclass),                  -- Chave primria da tabela
	id_cte BIGINT NOT NULL,                     -- Chave estrangeira da tabela OOBJ_CTE_ENVIO
	
	cteNormCargaVCarga NUMERIC(17,3),         -- Valor total da mercadoria
	cteNormCargaProPred VARCHAR(60),        -- Produto predominante
	cteNormCargaXOutCat VARCHAR(30),        -- Outras caractersticas da carga
	cteNormCargaVCargaAverb NUMERIC (17,3), --Valor da Carga para efeito de averbao
	
	aeroNMinu BIGINT,                  -- Nmero da Minuta
	aeroNOCA BIGINT,                   -- Nmero da Operacional do Conhecimento Areo
	aeroDPrev TIMESTAMP WITHOUT TIME ZONE,                  -- Data prevista da entrega
	--aeroXLAgEmi VARCHAR(20),                -- Loja Agente Emissor
	--aeroIdT VARCHAR(20),                    -- Identificao Interna do Tomador
	aeroTarifaCL CHAR(1),
	aeroTarifaCTar VARCHAR(2),             -- Cdigo da Tarifa
	aeroTarifaVTar NUMERIC(17,3),             -- Valor da Tarifa
	aeroNatCargaXDime VARCHAR(20),          -- Dimenso
	aeroNatCargaCInfManu VARCHAR(2000),       -- Informaes de manuseio
	--aeroNatCargaCIMP VARCHAR(2000),           -- Carga especial
	
	aquavVPrest NUMERIC(17,3),                -- Valor da Prestao Base de Clculo do AFRMM
	aquavVAFRMM VARCHAR(200),                -- AFRMM (Adicional de Frete para Renovao da Marinha Mercante)
	--aquavNBooking VARCHAR(10),              -- Nmero do Booking (reserva)
	--aquavNCtrl VARCHAR(10),                 -- Nmero de Controle
	aquavXNavio VARCHAR(60),                -- Identificao do Navio
	aquavXBalsa VARCHAR(190),                -- Identificador da Balsa
	aquavNViag BIGINT,                 -- Nmero da Viagem
	aquavDirec CHAR(1),                 -- Direo:N-Norte, L-Leste, S-Sul, O-Oeste
	--aquavPrtEmb VARCHAR(60),                -- Porto de Embarque
	--aquavPrtTrans VARCHAR(60),              -- Porto de Transbordo
	--aquavPrtDest VARCHAR(60),               -- Porto de Destino
	aquavTpNav SMALLINT,                 -- Tipo de Navegao
	aquavIrin VARCHAR(10),                  -- Irin do navio sempre dever ser informado
	
	dutoVTar NUMERIC(17,3),                   -- Valor da tarifa
	dutoDIni TIMESTAMP WITHOUT TIME ZONE,                   -- Data de Incio da prestao do servio
	dutoDFim TIMESTAMP WITHOUT TIME ZONE,                   -- Data de Fim da prestao do servio
	
	ferrovTpTraf SMALLINT,               -- Tipo de Trfego
	ferrovTrafMutRespFat SMALLINT,       -- Responsvel pelo Faturamento
	ferrovTrafMutFerrEmi SMALLINT,       -- Ferrovia Emitente do CTe
	ferrovFluxo VARCHAR(10),                -- Fluxo Ferrovirio
	--ferrovIdTrem VARCHAR(10),               -- Identificao do trem
	ferroTrafchCTeOrigem VARCHAR(44), 		-- Chave de acesso do CT-e emitido pelo ferrovia de origem
	ferrovVFrete NUMERIC(17,3),               -- Valor do Frete
	
	rodoRNTRC VARCHAR(20),                  -- RNTC
	--rodoDPrev TIMESTAMP WITHOUT TIME ZONE,                  -- Data prevista para entrega da carga no Recebedor
	--rodoLota SMALLINT,                   -- Indicador de Lotao
	--rodoCIOT BIGINT,                   -- Cdigo Identificador da Operao de Transporte
	--rodoLacre VARCHAR(2000),                  -- Lacres do Modal Rodovirio

	multiModalCotm VARCHAR(200),             -- Nmero do certificado do operador de transporte multimodal
	multiModalIndNegociavel SMALLINT,    -- Indicador negocivel

	fatNFat VARCHAR(60),                    -- Nmero da fatura
	fatVOrig NUMERIC(17,3),                   -- Valor original da fatura
	fatVDesc NUMERIC(17,3),                   -- Valor do desconto da fatura
	fatVLiq NUMERIC(17,3),                    -- Valor lquido da fatura
	
	infCteSubChCte VARCHAR(44),             -- Chave de acesso do CT-e a ser substitudo (original)
	infCteSubRefNFe VARCHAR(44),            -- Chave de acesso da NF-e emitida pelo Tomador
	infCteSubRefNFCNPJ VARCHAR(14),         -- CNPJ do Emitente
	infCteSubRefNFMod VARCHAR(10),          -- Modelo do Documento Fiscal
	infCteSubRefNFSerie SMALLINT,        -- Srie do documento fiscal
	infCteSubRefNFSubserie SMALLINT,     -- Subserie do documento fiscal
	infCteSubRefNFNro INTEGER,          -- Nmero do documento fiscal
	infCteSubRefNFValor NUMERIC(17,3),        -- Valor do documento fiscal
	infCteSubRefNFDEmi TIMESTAMP WITHOUT TIME ZONE,         -- Data de emisso do documento fiscal
	infCteSubRefCTe VARCHAR(44),            -- Chave de acesso do CT-e emitido pelo Tomador
	infCteSubRefCteAnu VARCHAR(44),          -- Chave de acesso do CT-e de Anulao
	infCteSubIndAlteraToma CHAR(1)          -- Indicao de CT-e Alterao de Tomador
	
	infCTeGlobxObs VARCHAR(256),           -- Preencher com informaes adicionais, legislao do regime especial, etc
	infCTeServVincChCTe VARCHAR(1500),		--Informaes dos Cte-s multimodal vinculados separados por ponto-e-vrgula (;)
	
	cteCompChave VARCHAR(44),               -- Chave do CT-e complementado

	cteAnuChaveCTe VARCHAR(44),             -- Chave de acesso do CT-e original a ser anulado e substitudo
	cteAnuDEmi TIMESTAMP WITHOUT TIME ZONE,                 -- Data de emisso da declarao do tomador no contribuinte do ICMS	
	
	status_extraido BOOLEAN DEFAULT FALSE,
	CONSTRAINT oobj_cte_infcte_pkey PRIMARY KEY (id_infcte),
	CONSTRAINT oobj_cte_envio_fk FOREIGN KEY (id_cte)
		REFERENCES oobj_cte_envio (id_cte)
		MATCH SIMPLE
		ON UPDATE NO ACTION
		ON DELETE NO ACTION
);

CREATE INDEX CTE_INFCTE_IX_ID_CTE
ON OOBJ_CTE_INFCTE
USING btree
(id_cte);
