CREATE SEQUENCE SEQ_ID_CTE_EVENTOS
  INCREMENT 1
  MINVALUE 1
  MAXVALUE 9223372036854775807
  START 1
  CACHE 1;

ALTER TABLE SEQ_ID_CTE_EVENTOS
  OWNER TO postgres;

create table OOBJ_CTE_EVENTOS(
	id_evento BIGINT NOT NULL DEFAULT nextval('SEQ_ID_CTE_EVENTOS'::regclass),     -- Chave primária desta tabela
	versaoEvento CHARACTER VARYING(10), -- Versão do evento
	cOrgao INTEGER NOT NULL,        -- Código do órgão (UF)
	tpAmb INTEGER NOT NULL,         -- Tipo de ambiente
	autorEvento CHARACTER VARYING(100),   -- CNPJ do emitente do evento
	chCTe CHARACTER VARYING(100),         -- Chave de Acesso do CT-e associado
	dhEvento TIMESTAMP WITHOUT TIME ZONE,      -- Data e hora do evento
	tpEvento INTEGER NOT NULL,      -- Tipo do evento
	nSeqEvento INTEGER NOT NULL,    -- Número sequencial do evento

	-- Dados de evento de Cancelamento (tpEvento = 110111)
	cancNProt CHARACTER VARYING(100),     -- Número de protocolo de autorização
	cancXJust CHARACTER VARYING(500),     -- Justificativa de cancelamento

	-- Dados de evento de Registro Multimodal (tpEvento = 110160)
	regMModalXRegistro CHARACTER VARYING(2000), -- Informação complementar sobre o registro (texto livre)
	regMModalNDoc CHARACTER VARYING(100),      -- Número do documento lançado no multimodal

	-- Dados de Evento Prévio de Emissão em Contingência (EPEC, tpEvento = 110113)
	epecXJust CHARACTER VARYING(100),     -- Justificativa de entrada em contingência
	epecVICMS NUMERIC(17, 3),     -- Valor do ICMS
	epecVTPrest NUMERIC(17, 3),   -- Valor total da prestação do serviço
	epecVCarga NUMERIC(17, 3),    -- Valor total da carga
	epecToma INTEGER,      -- Tomador do Serviço
	epecTomaUF CHARACTER VARYING(10),    -- UF do Tomador do Serviço
	epecTomaCPFCNPJ CHARACTER VARYING(20),  -- CPF ou CNPJ do Tomador do Serviço
	epecTomaIE CHARACTER VARYING(100),    -- Inscrição Estadual do Tomador do Serviço
	epecModal INTEGER,     -- Modal
	epecUFIni CHARACTER VARYING(10),     -- UF do início da prestação
	epecUFFim CHARACTER VARYING(10),      -- UF do término da prestação
	status_extraido BOOLEAN DEFAULT FALSE,
	
	-- Dados de Evento de Prestação de serviço em desacordo
	prestDesIndicador INTEGER, 
	prestDesXObs	CHARACTER VARYING(256),
	
	--3.00A
	--INFORMAÇÃO EPEC VERSÃO 3.00A
	epecVICMSST NUMERIC(17, 3),  --Valor do ICMS ST
	
	--3.00A
	--INFORMAÇÃO COMPROVANTE DE ENTREGA ELETRONICO 
	ceeNProt CHARACTER VARYING(15),
	ceeNDoc CHARACTER VARYING(20),
	ceeDhEntrega CHARACTER VARYING(60),
	ceeXNome CHARACTER VARYING(60),
	ceeLatitude CHARACTER VARYING(255),
	ceeLongitude CHARACTER VARYING(255),
	ceeHashEntrega CHARACTER VARYING(255),
	ceeDhHashEntrega CHARACTER VARYING(60),	
	
	--3.00A
	--INFORMAÇÃO CANCELAMENTO DO COMPROVANTE DE ENTREGA ELETRONICO 
	cceeNProt CHARACTER VARYING(15),
	cceeNProtCE CHARACTER VARYING(15)
	
	CONSTRAINT oobj_cte_eventos_pkey PRIMARY KEY (id_evento)
);

ALTER TABLE OOBJ_CTE_EVENTOS OWNER TO postgres;

CREATE INDEX CTE_EVENTOS_IX_CH_CTE
ON OOBJ_CTE_EVENTOS
USING btree
(chCTe);
